---
title: "Interface"
---

This section of the documentation focuses on the design of the interface
and some of the reasons for these decisions. It is split into the
following documents:

- The [Inputs](inputs.qmd) accepted by Flower.
- The [Outputs](outputs.qmd), including the different styles for
  generating documentation from the `datapackage.json` file.
- The [Command Line Interface](cli.qmd) that forms the main entry point.
- The [Configuration settings](config.qmd) as a Python class and within
  a file.
- The [Python interface](python.qmd) that contains the Python code that
  powers the CLI Python functions.
